@@ -475,70 +475,49 @@ from data.models.models import HardwareStats, DataTransformer, DataTransformerCo
 
 # DataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer, fk_name='data_transformer_parent',
 #                                                      extra=1,exclude =['updated_at','created_at'],formset=DataTransformerForm)
-DataConstantsTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformerConstants, extra=1,
-                                                              exclude=['updated_at', 'created_at'])
-HardwareTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareDataTransformer, extra=1,
-                                                         exclude=['updated_at', 'created_at'])
-HardwareStatsTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareStatsDataTransformer, extra=1,
-                                                              exclude=['updated_at', 'created_at'])
+
+class DataConstantsTransformerForm(forms.ModelForm):
+    id = forms.CharField(required=False,
+                         widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+    type = forms.CharField(required=False,
+                                widget=forms.TextInput(attrs={'class': 'form-control'}))
+
+    index = forms.CharField(required=False,
+                                              widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+    value = forms.CharField(required=False,
+                           widget=forms.TextInput(attrs={'class': 'form-control'}))
+    class Meta:
+        model = DataTransformerConstants
+        fields = ('__all__')
+
+class HardwareTransformerForm(forms.ModelForm):
+    id = forms.CharField(required=False,
+                         widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+    index = forms.CharField(required=False,
+                            widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+
+
+
+    class Meta:
+        model = HardwareDataTransformer
+        fields = ('__all__')
+
+class HardwareStatsTransformerForm(forms.ModelForm):
+    id = forms.CharField(required=False,
+                         widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+    index = forms.CharField(required=False,
+                            widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+
+    class Meta:
+        model = HardwareStatsDataTransformer
+        fields = ('__all__')
+
+DataConstantsTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformerConstants, extra=1,form=DataConstantsTransformerForm)
+HardwareTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareDataTransformer, extra=1,form=HardwareTransformerForm)
+HardwareStatsTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareStatsDataTransformer, extra=1,form=HardwareStatsTransformerForm)
 
 from django.utils.safestring import mark_safe
 
-# class DataTransformerForm(BaseInlineFormSet):
-
-    # def add_fields(self, form, index):
-    #     super(DataTransformerForm, self).add_fields(form, index)
-    #
-        # if hasattr(form.instance, 'accessory') and form.instance.accessory is not None:
-        #     dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,formset=self.__class__,
-        #                                                          fk_name='parent', form=DataTransform
-        #                                                          )
-        #     form.nested_data_transformer_form = dataTransformerInlineFormset(
-        #         instance=form.instance,
-        #         data=form.data if form.is_bound else None,
-        #         files=form.files if form.is_bound else None,
-        #         initial=[{'parent': form.instance}]
-        #     )
-        #
-        #
-        #
-        # form.nested_constants_form = DataConstantsTransformerInlineFormset(
-        #     instance=form.instance,
-        #     data=form.data if form.is_bound else None,
-        #     files=form.files if form.is_bound else None
-        # )
-        #
-        # form.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
-        #     instance=form.instance,
-        #     data=form.data if form.is_bound else None,
-        #     files=form.files if form.is_bound else None
-        # )
-        #
-        # form.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
-        #     instance=form.instance,
-        #     data=form.data if form.is_bound else None,
-        #     files=form.files if form.is_bound else None
-        # )
-    #
-    # def as_p(self):
-    #     # super(self.__class__,self).as_p()
-    #     forms = ''
-    #     for form in self:
-    #         forms = '   '.join([forms,form.as_p()])
-    #         if hasattr(form, 'nested_data_transformer_form') and form.nested_data_transformer_form is not None:
-    #             forms = '       -'.join([forms,form.nested_data_transformer_form.as_p()])
-    #         if hasattr(form, 'nested_constants_form') and form.nested_constants_form is not None:
-    #
-    #             forms = ' '.join([forms,form.nested_constants_form.as_p()])
-    #         if hasattr(form, 'nested_hardware_outputs_form') and form.nested_hardware_outputs_form is not None:
-    #
-    #             forms = ' '.join([forms,form.nested_hardware_outputs_form.as_p()])
-    #         if hasattr(form, 'nested_hardware_stats_form') and form.nested_hardware_stats_form is not None:
-    #
-    #             forms = ' '.join([forms,form.nested_hardware_stats_form.as_p()])
-    #
-    #     return mark_safe(str(self.management_form) + '\n' + forms)
-
 
 class DataTransform(forms.ModelForm):
     id = forms.CharField(required=False,
@@ -594,7 +573,10 @@ class DataTransform(forms.ModelForm):
     def as_p(self):
         print('wtf')
         print('instance: ' + str(self.instance.id))
-        forms = super(self.__class__,self).as_p()
+        forms = '<div class="row"><div class="col-6">'
+
+        forms = super(DataTransform,self).as_p()
+        forms = forms + '</div><div class="col-6">'
 
         if hasattr(self, 'nested_constants_form') and self.nested_constants_form is not None:
             forms = forms + '\n  -' + self.nested_constants_form.as_p()
@@ -605,6 +587,8 @@ class DataTransform(forms.ModelForm):
         if hasattr(self, 'nested_data_transformer_form') and self.nested_data_transformer_form is not None:
             print('netdatatransform with number elements: ' + str(len(self.nested_data_transformer_form)))
             forms = forms + '\n       -' + ' '.join(form.as_p() for form in self.nested_data_transformer_form)
+        forms = forms + '</div></div>'
+
         return mark_safe(forms)
 
     class Meta:
@@ -661,8 +645,10 @@ class DataTransformRoot(forms.ModelForm):
     def as_p(self):
         print('root')
         print('instance: ' + str(self.instance.id))
-        forms = super(self.__class__,self).as_p()
+        forms = '<div class="row"><div class="col-6">'
 
+        forms = forms + super(DataTransformRoot,self).as_p()
+        forms = forms + '</div><div class="col-6">'
         if hasattr(self, 'nested_constants_form') and self.nested_constants_form is not None:
             forms = forms + '\n  -' + self.nested_constants_form.as_p()
         if hasattr(self, 'nested_hardware_outputs_form') and self.nested_hardware_outputs_form is not None:
@@ -672,6 +658,7 @@ class DataTransformRoot(forms.ModelForm):
         if hasattr(self, 'nested_data_transformer_form') and self.nested_data_transformer_form is not None:
             print('netdatatransform with number elements: ' + str(len(self.nested_data_transformer_form)))
             forms = forms + '\n       -' +  ' '.join(form.as_p() for form in self.nested_data_transformer_form)
+        forms = forms + '</div></div>'
         return mark_safe(forms)
 
     class Meta:
