@@ -6,6 +6,7 @@ import time
 from polymorphic.models import PolymorphicModel
 from mptt.models import MPTTModel, TreeForeignKey
 
+
 class Hub(models.Model):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
     ip = models.URLField()
@@ -86,11 +87,13 @@ class VEML7700(Hardware):
     scl = models.IntegerField()
     sda = models.IntegerField()
 
+
 class PMSA0031(Hardware):
     scl = models.IntegerField()
     sda = models.IntegerField()
     reset = models.IntegerField()
 
+
 class HardwareChannelTypes(models.Model):
     hardware_type = models.CharField(
         max_length=20
@@ -147,9 +150,7 @@ class Channel(models.Model):
         ]
 
 
-
 class HardwareIO(PolymorphicModel):
-
     SPI = 'SPI'
     Serial = 'Serial'
     PWM = 'PWM'
@@ -159,13 +160,16 @@ class HardwareIO(PolymorphicModel):
     PiPicoACAnalog = 'Pi Pico AC Analog'
     PiPicoAnalog = 'Pi Pico Analog'
     PiGPIO = 'Pi GPIO'
-    hardware_io_types_choices = [(SPI,SPI),(Serial,Serial),(PWM,PWM),(I2C,I2C),(DeviceFile,DeviceFile),(MCPChannel,MCPChannel),(PiPicoAnalog,PiPicoAnalog),(PiPicoACAnalog,PiPicoACAnalog),(PiGPIO,PiGPIO)]
+    hardware_io_types_choices = [(SPI, SPI), (Serial, Serial), (PWM, PWM), (I2C, I2C), (DeviceFile, DeviceFile),
+                                 (MCPChannel, MCPChannel), (PiPicoAnalog, PiPicoAnalog),
+                                 (PiPicoACAnalog, PiPicoACAnalog), (PiGPIO, PiGPIO)]
 
     label = models.CharField(max_length=255, null=True)
 
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
-    parent_hardware = models.ForeignKey(Hardware, on_delete=models.CASCADE, blank=True, null=True,related_name="%(app_label)s_%(class)s_related",
-        related_query_name="%(app_label)s_%(class)ss")
+    parent_hardware = models.ForeignKey(Hardware, on_delete=models.CASCADE, blank=True, null=True,
+                                        related_name="%(app_label)s_%(class)s_related",
+                                        related_query_name="%(app_label)s_%(class)ss")
     child_hardware = models.ForeignKey(Hardware, on_delete=models.CASCADE, blank=True, null=True)
     child_channel = models.ForeignKey(Channel, on_delete=models.CASCADE, blank=True, null=True)
     type = models.CharField(max_length=25, choices=hardware_io_types_choices, default=PiPicoAnalog)
@@ -186,6 +190,7 @@ class HardwareIO(PolymorphicModel):
             models.Index(fields=['id', 'parent_hardware', 'child_channel']),
         ]
 
+
 class PiPins(models.Model):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
     hardware_io = models.ForeignKey(HardwareIO, on_delete=models.CASCADE, blank=True, null=True)
@@ -196,39 +201,48 @@ class PiPins(models.Model):
             models.Index(fields=['hardware_io']),
         ]
 
+
 class SPIIo(HardwareIO):
     sck = models.IntegerField()
     miso = models.IntegerField()
     mosi = models.IntegerField()
 
+
 class SerialIo(HardwareIO):
     port = models.CharField(max_length=100)
 
+
 class PwmIo(HardwareIO):
     en = models.IntegerField()
     duty_max = models.IntegerField()
     duty_min = models.IntegerField()
     freq = models.IntegerField()
 
+
 class I2cIo(HardwareIO):
     scl = models.IntegerField()
     sda = models.IntegerField()
 
+
 class DeviceFileIo(HardwareIO):
     base_dir = models.CharField(max_length=100, null=True)
     device_file = models.CharField(max_length=100, null=True)
 
+
 class MCPAnalogIo(HardwareIO):
     channel_index = models.IntegerField()
 
+
 class PiPicoAnalogIo(HardwareIO):
     pin = models.IntegerField()
 
+
 class PiPicoACAnalogIo(HardwareIO):
     pin = models.IntegerField()
 
+
 class PiGpio(HardwareIO):
-    pin =  models.IntegerField()
+    pin = models.IntegerField()
 
 
 class Accessory(models.Model):
@@ -284,9 +298,11 @@ class HardwareConfig(models.Model):
             models.Index(fields=['id', 'hardware']),
         ]
 
+
 class HardwareStats(models.Model):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
-    hardware = models.ForeignKey(Hardware, on_delete=models.CASCADE, blank=True, null=True, default=None)
+    hardware = models.ManyToManyField(Channel)
+
     type = models.CharField(max_length=255, null=True)
     value = models.FloatField(null=True)
     updated_at = models.DateTimeField(auto_now=True)
@@ -305,17 +321,26 @@ class HardwareStats(models.Model):
         ]
 
 
-
-
 class DataTransformer(MPTTModel):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
     accessory = models.ForeignKey(
         Accessory,
         on_delete=models.CASCADE,
-        blank = True,
+        blank=True,
         null=False
     )
-    type = models.CharField(max_length=255,  blank=True, null=True, default=None)
+
+    class Type(models.TextChoices):
+        SUM = 'SUM'
+        PRODUCT = 'PRODUCT'
+        MAX = 'MAX'
+        MIN = 'MIN'
+        MEAN = 'MEAN'
+
+
+    type = models.CharField(
+        max_length=15, blank=True, null=True, default=None
+    )
     parent = TreeForeignKey('self', on_delete=models.CASCADE, null=True, blank=True, related_name='children')
     updated_at = models.DateTimeField(auto_now=True)
     created_at = models.DateTimeField(auto_now_add=True)
@@ -329,7 +354,7 @@ class DataTransformer(MPTTModel):
 
     class Meta:
         indexes = [
-            models.Index(fields=['id','accessory']),
+            models.Index(fields=['id', 'accessory']),
         ]
 
     class MPTTMeta:
@@ -354,13 +379,14 @@ class DataTransformerConstants(models.Model):
 
     class Meta:
         indexes = [
-            models.Index(fields=['id','data_transformer']),
+            models.Index(fields=['id', 'data_transformer']),
         ]
 
+
 class HardwareDataTransformer(models.Model):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
-    hardware = models.ForeignKey(Hardware, on_delete=models.CASCADE, blank=True, null=True, default=None)
-    data_transformer = models.ForeignKey(DataTransformer,on_delete=models.CASCADE, blank=True, null=True, default=None)
+    hardware = models.ManyToManyField(Channel)
+    data_transformer = models.ForeignKey(DataTransformer, on_delete=models.CASCADE, blank=True, null=True, default=None)
     index = models.IntegerField(blank=True, null=True, default=None)
     updated_at = models.DateTimeField(auto_now=True)
     created_at = models.DateTimeField(auto_now_add=True)
@@ -374,13 +400,14 @@ class HardwareDataTransformer(models.Model):
 
     class Meta:
         indexes = [
-            models.Index(fields=['id','data_transformer','hardware']),
+            models.Index(fields=['id', 'data_transformer', 'hardware']),
         ]
 
+
 class HardwareStatsDataTransformer(models.Model):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
     hardware_stat = models.ForeignKey(HardwareStats, on_delete=models.CASCADE, blank=True, null=True, default=None)
-    data_transformer = models.ForeignKey(DataTransformer,on_delete=models.CASCADE, blank=True, null=True, default=None)
+    data_transformer = models.ForeignKey(DataTransformer, on_delete=models.CASCADE, blank=True, null=True, default=None)
     index = models.IntegerField()
     updated_at = models.DateTimeField(auto_now=True)
     created_at = models.DateTimeField(auto_now_add=True)
@@ -394,9 +421,10 @@ class HardwareStatsDataTransformer(models.Model):
 
     class Meta:
         indexes = [
-            models.Index(fields=['id','data_transformer']),
+            models.Index(fields=['id', 'data_transformer']),
         ]
 
+
 class Calibration(models.Model):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
     type = models.CharField(max_length=255, null=True)
@@ -445,4 +473,4 @@ class Category(models.Model):
 
 
 class AccessoryType(models.Model):
-    type = models.CharField(max_length=255, null=True)
\ No newline at end of file
+    type = models.CharField(max_length=255, null=True)
